@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import time
 import unittest
 
@@ -26,5 +23,5 @@ class TestMemoize(unittest.TestCase):
         self.assertTrue(time.time() - start < 0.1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
